# Business Capability Modeling Guidelines
### On this page
  * [Definition](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines#definition)
  * [Description](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines#description)
  * [Guidelines and Best Practices](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines#guidelines-and-best-practices)
  * [Antipatterns](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines#antipatterns)
  * [Applicable Use Cases](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines#applicable-use-cases)
  * [Insights from Business Capability Fact Sheet](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines#insights-from-business-capability-fact-sheet)
  * [Related Information](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines#related-information)


This page covers modeling guidelines for business capabilities. Learn about best practices and applicable use cases, and avoid common antipatterns.
